$.fn.drawDashed = function(args) {
	
	var ctx, e,
		params = $.extend({}, $.jCanvas.prefs, args);
	
	for (e=0; e<this.length; e+=1) {
	
		ctx = this[e].getContext('2d');
	
		// default value of dash length is 6
		if (params.dashLength === undefined) params.dashLength = 6;
	
		// calculate dx and dy
		var dx = params.x2 - params.x1,
		  dy = params.y2 - params.y1;
	
		// calculate distance of line
		var distance = Math.sqrt(Math.pow(dx, 2) + Math.pow(dy, 2));
	
		// "fixate" the dash length so that we get an odd whole number of
		// dashes, and don't worry about getting fractional dash lengths.
		var chunks;
		if (Math.floor(distance / params.dashLength) % 2 == 1)
			chunks = Math.floor(distance / params.dashLength);
		else
			chunks = Math.ceil(distance / params.dashLength);
		params.dashLength = distance / chunks;
		
		// ratio of dx and dy to distance gives us the amount of increase per unit
		var ratio = { x: dx/distance, y: dy/distance };
	
		// set up our iterator
		var current = { x: params.x1, y: params.y1, distance: 0 },
			draw = false;
	
		// Set stroke properties
		ctx.strokeStyle = params.strokeStyle;
		ctx.lineWidth = params.strokeWidth;
	
		// set up the context
		ctx.save();
		ctx.beginPath();
	
		// move to the start position
		ctx.moveTo(params.x1, params.y1);
	
		// iterate until current == end
		while (current.distance < distance) {
			// add the ratio for each dimension times the length to the iterator
			current.x += (ratio.x * params.dashLength);
			current.y += (ratio.y * params.dashLength);
	
			// bump whether or not we're drawing
			draw = !draw;
	
			// if we're drawing, line-to, otherwise move-to
			if (draw)	 ctx.lineTo(current.x, current.y);
			else       ctx.moveTo(current.x, current.y);
	
			current.distance += params.dashLength;
		}
	
		// we're done, stroke the line, close the path and restore the context
		ctx.stroke();
		ctx.closePath();
		ctx.restore();
	
	}
};
